##  Layout Modes
In matrix reports, the layout can be changed for different visualizations as well as for better condensation of information. To get to the different layout modes, simply use the Layout Mode drop-down menu and pick a mode.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c6f207a4410148a85ad607eef9c72_LowRes.png)
Take for e.g., the Rolled-up Layout, in this layout the clusters get aggregated by the chosen view, by rolling up the contents of every cluster or cell.
![Left side: Matrix Report with detailed layout Right side: Matrix Report with Rolled-up Layout](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c0f347a441014b86fa475de8435e6_LowRes.png)
Left: Matrix Report with Detailed Layout, Right: Matrix Report with Rolled-up Layout
The Rolled-up Layout allows for easier consumption of more information and also to quickly spot and identify the issues in your matrix report.
**Tip**
You can adjust the column width by dragging the column border to the desired size. Save your changes if you want to keep the adjusted layout. Adjusting the column width lets you view the full names of your fact sheets.
